AdaptiveMtFile

Struct AdaptiveMtFile 

pub struct AdaptiveMtFile {
    pub create_time: Option<DateTime<Utc>>,
    pub display_name: Option<String>,
    pub entry_count: Option<i32>,
    pub name: Option<String>,
    pub update_time: Option<DateTime<Utc>>,
}
An AdaptiveMtFile.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

create_time: Option<DateTime<Utc>>

Output only. Timestamp when this file was created.

display_name: Option<String>

The file’s display name.

entry_count: Option<i32>

The number of entries that the file contains.

name: Option<String>

Required. The resource name of the file, in form of projects/{project-number-or-id}/locations/{location_id}/adaptiveMtDatasets/{dataset}/adaptiveMtFiles/{file}

update_time: Option<DateTime<Utc>>

Output only. Timestamp when this file was last updated.