pub struct AdaptiveMtSentence {
pub create_time: Option<DateTime<Utc>>,
pub name: Option<String>,
pub source_sentence: Option<String>,
pub target_sentence: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
An AdaptiveMt sentence entry.
This type is not used in any activity, and only used as part of another schema.
Fields
create_time: Option<DateTime<Utc>>Output only. Timestamp when this sentence was created.
name: Option<String>Required. The resource name of the file, in form of projects/{project-number-or-id}/locations/{location_id}/adaptiveMtDatasets/{dataset}/adaptiveMtFiles/{file}/adaptiveMtSentences/{sentence}
source_sentence: Option<String>Required. The source sentence.
target_sentence: Option<String>Required. The target sentence.
update_time: Option<DateTime<Utc>>Output only. Timestamp when this sentence was last updated.