pub struct AdaptiveMtTranslateResponse {
pub glossary_translations: Option<Vec<AdaptiveMtTranslation>>,
pub language_code: Option<String>,
pub translations: Option<Vec<AdaptiveMtTranslation>>,
}Expand description
An AdaptiveMtTranslate response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations adaptive mt translate projects (response)
Fields
glossary_translations: Option<Vec<AdaptiveMtTranslation>>Text translation response if a glossary is provided in the request. This could be the same as ‘translation’ above if no terms apply.
language_code: Option<String>Output only. The translation’s language code.
translations: Option<Vec<AdaptiveMtTranslation>>Output only. The translation.