Dataset

Struct Dataset 

pub struct Dataset {
    pub create_time: Option<DateTime<Utc>>,
    pub display_name: Option<String>,
    pub example_count: Option<i32>,
    pub name: Option<String>,
    pub source_language_code: Option<String>,
    pub target_language_code: Option<String>,
    pub test_example_count: Option<i32>,
    pub train_example_count: Option<i32>,
    pub update_time: Option<DateTime<Utc>>,
    pub validate_example_count: Option<i32>,
}
A dataset that hosts the examples (sentence pairs) used for translation models.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

create_time: Option<DateTime<Utc>>

Output only. Timestamp when this dataset was created.

display_name: Option<String>

The name of the dataset to show in the interface. The name can be up to 32 characters long and can consist only of ASCII Latin letters A-Z and a-z, underscores (_), and ASCII digits 0-9.

example_count: Option<i32>

Output only. The number of examples in the dataset.

name: Option<String>

The resource name of the dataset, in form of projects/{project-number-or-id}/locations/{location_id}/datasets/{dataset_id}

source_language_code: Option<String>

The BCP-47 language code of the source language.

target_language_code: Option<String>

The BCP-47 language code of the target language.

test_example_count: Option<i32>

Output only. Number of test examples (sentence pairs).

train_example_count: Option<i32>

Output only. Number of training examples (sentence pairs).

update_time: Option<DateTime<Utc>>

Output only. Timestamp when this dataset was last updated.

validate_example_count: Option<i32>

Output only. Number of validation examples (sentence pairs).