pub struct DetectedLanguage {
pub confidence: Option<f32>,
pub language_code: Option<String>,
}Expand description
The response message for language detection.
This type is not used in any activity, and only used as part of another schema.
Fields
confidence: Option<f32>The confidence of the detection result for this language.
language_code: Option<String>The ISO-639 language code of the source content in the request, detected automatically.