pub struct DocumentInputConfig {
pub content: Option<Vec<u8>>,
pub gcs_source: Option<GcsSource>,
pub mime_type: Option<String>,
}Expand description
A document translation request input config.
This type is not used in any activity, and only used as part of another schema.
Fields
content: Option<Vec<u8>>Document’s content represented as a stream of bytes.
gcs_source: Option<GcsSource>Google Cloud Storage location. This must be a single file. For example: gs://example_bucket/example_file.pdf
mime_type: Option<String>Specifies the input document’s mime_type. If not specified it will be determined using the file extension for gcs_source provided files. For a file provided through bytes content the mime_type must be provided. Currently supported mime types are: - application/pdf - application/vnd.openxmlformats-officedocument.wordprocessingml.document - application/vnd.openxmlformats-officedocument.presentationml.presentation - application/vnd.openxmlformats-officedocument.spreadsheetml.sheet