pub struct Example {
pub name: Option<String>,
pub source_text: Option<String>,
pub target_text: Option<String>,
pub usage: Option<String>,
}Expand description
A sentence pair.
This type is not used in any activity, and only used as part of another schema.
Fields
name: Option<String>Output only. The resource name of the example, in form of projects/{project-number-or-id}/locations/{location_id}/datasets/{dataset_id}/examples/{example_id}
source_text: Option<String>Sentence in source language.
target_text: Option<String>Sentence in target language.
usage: Option<String>Output only. Usage of the sentence pair. Options are TRAIN|VALIDATION|TEST.