pub struct GlossaryInputConfig {
pub gcs_source: Option<GcsSource>,
}Expand description
Input configuration for glossaries.
This type is not used in any activity, and only used as part of another schema.
Fields
gcs_source: Option<GcsSource>Required. Google Cloud Storage location of glossary data. File format is determined based on the filename extension. API returns [google.rpc.Code.INVALID_ARGUMENT] for unsupported URI-s and file formats. Wildcards are not allowed. This must be a single file in one of the following formats: For unidirectional glossaries: - TSV/CSV (.tsv/.csv): Two column file, tab- or comma-separated. The first column is source text. The second column is target text. No headers in this file. The first row contains data and not column names. - TMX (.tmx): TMX file with parallel data defining source/target term pairs. For equivalent term sets glossaries: - CSV (.csv): Multi-column CSV file defining equivalent glossary terms in multiple languages. See documentation for more information - glossaries.