pub struct ImportAdaptiveMtFileResponse {
pub adaptive_mt_file: Option<AdaptiveMtFile>,
}Expand description
The response for importing an AdaptiveMtFile
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
adaptive_mt_file: Option<AdaptiveMtFile>Output only. The Adaptive MT file that was imported.