pub struct ListAdaptiveMtDatasetsResponse {
pub adaptive_mt_datasets: Option<Vec<AdaptiveMtDataset>>,
pub next_page_token: Option<String>,
}Expand description
A list of AdaptiveMtDatasets.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations adaptive mt datasets list projects (response)
Fields
adaptive_mt_datasets: Option<Vec<AdaptiveMtDataset>>Output only. A list of Adaptive MT datasets.
next_page_token: Option<String>Optional. A token to retrieve a page of results. Pass this value in the [ListAdaptiveMtDatasetsRequest.page_token] field in the subsequent call to ListAdaptiveMtDatasets method to retrieve the next page of results.