pub struct ListAdaptiveMtSentencesResponse {
pub adaptive_mt_sentences: Option<Vec<AdaptiveMtSentence>>,
pub next_page_token: Option<String>,
}Expand description
List AdaptiveMt sentences response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
adaptive_mt_sentences: Option<Vec<AdaptiveMtSentence>>Output only. The list of AdaptiveMtSentences.
next_page_token: Option<String>Optional.