pub struct ListDatasetsResponse {
pub datasets: Option<Vec<Dataset>>,
pub next_page_token: Option<String>,
}Expand description
Response message for ListDatasets.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations datasets list projects (response)
Fields
datasets: Option<Vec<Dataset>>The datasets read.
next_page_token: Option<String>A token to retrieve next page of results. Pass this token to the page_token field in the ListDatasetsRequest to obtain the corresponding page.