pub struct ListExamplesResponse {
pub examples: Option<Vec<Example>>,
pub next_page_token: Option<String>,
}Expand description
Response message for ListExamples.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations datasets examples list projects (response)
Fields
examples: Option<Vec<Example>>The sentence pairs.
next_page_token: Option<String>A token to retrieve next page of results. Pass this token to the page_token field in the ListExamplesRequest to obtain the corresponding page.