pub struct ListGlossaryEntriesResponse {
pub glossary_entries: Option<Vec<GlossaryEntry>>,
pub next_page_token: Option<String>,
}Expand description
Response message for ListGlossaryEntries
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
glossary_entries: Option<Vec<GlossaryEntry>>Optional. The Glossary Entries
next_page_token: Option<String>Optional. A token to retrieve a page of results. Pass this value in the [ListGLossaryEntriesRequest.page_token] field in the subsequent calls.