pub struct ListModelsResponse {
pub models: Option<Vec<Model>>,
pub next_page_token: Option<String>,
}Expand description
Response message for ListModels.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations models list projects (response)
Fields
models: Option<Vec<Model>>The models read.
next_page_token: Option<String>A token to retrieve next page of results. Pass this token to the page_token field in the ListModelsRequest to obtain the corresponding page.