pub struct Romanization {
pub detected_language_code: Option<String>,
pub romanized_text: Option<String>,
}Expand description
A single romanization response.
This type is not used in any activity, and only used as part of another schema.
Fields
detected_language_code: Option<String>The ISO-639 language code of source text in the initial request, detected automatically, if no source language was passed within the initial request. If the source language was passed, auto-detection of the language does not occur and this field is empty.
romanized_text: Option<String>Romanized text. If an error occurs during romanization, this field might be excluded from the response.