pub struct RomanizeTextResponse {
pub romanizations: Option<Vec<Romanization>>,
}Expand description
The response message for synchronous romanization.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations romanize text projects (response)
- romanize text projects (response)
Fields
romanizations: Option<Vec<Romanization>>Text romanization responses. This field has the same length as contents.