pub struct SupportedLanguage {
pub display_name: Option<String>,
pub language_code: Option<String>,
pub support_source: Option<bool>,
pub support_target: Option<bool>,
}Expand description
A single supported language response corresponds to information related to one supported language.
This type is not used in any activity, and only used as part of another schema.
Fields
display_name: Option<String>Human-readable name of the language localized in the display language specified in the request.
language_code: Option<String>Supported language code, generally consisting of its ISO 639-1 identifier, for example, ‘en’, ‘ja’. In certain cases, ISO-639 codes including language and region identifiers are returned (for example, ‘zh-TW’ and ‘zh-CN’).
support_source: Option<bool>Can be used as a source language.
support_target: Option<bool>Can be used as a target language.