pub struct SupportedLanguages {
pub languages: Option<Vec<SupportedLanguage>>,
}Expand description
The response message for discovering supported languages.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations get supported languages projects (response)
- get supported languages projects (response)
Fields
languages: Option<Vec<SupportedLanguage>>A list of supported language responses. This list contains an entry for each language the Translation API supports.