pub struct TranslateDocumentResponse {
pub document_translation: Option<DocumentTranslation>,
pub glossary_config: Option<TranslateTextGlossaryConfig>,
pub glossary_document_translation: Option<DocumentTranslation>,
pub model: Option<String>,
}Expand description
A translated document response message.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations translate document projects (response)
Fields
document_translation: Option<DocumentTranslation>Translated document.
glossary_config: Option<TranslateTextGlossaryConfig>The glossary_config used for this translation.
glossary_document_translation: Option<DocumentTranslation>The document’s translation output if a glossary is provided in the request. This can be the same as [TranslateDocumentResponse.document_translation] if no glossary terms apply.
model: Option<String>Only present when ‘model’ is present in the request. ‘model’ is normalized to have a project number. For example: If the ‘model’ field in TranslateDocumentRequest is: projects/{project-id}/locations/{location-id}/models/general/nmt then model here would be normalized to projects/{project-number}/locations/{location-id}/models/general/nmt.