pub struct TranslateTextRequest {
pub contents: Option<Vec<String>>,
pub glossary_config: Option<TranslateTextGlossaryConfig>,
pub labels: Option<HashMap<String, String>>,
pub mime_type: Option<String>,
pub model: Option<String>,
pub source_language_code: Option<String>,
pub target_language_code: Option<String>,
pub transliteration_config: Option<TransliterationConfig>,
}Expand description
The request message for synchronous translation.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations translate text projects (request)
- translate text projects (request)
Fields
contents: Option<Vec<String>>Required. The content of the input in string format. We recommend the total content be less than 30,000 codepoints. The max length of this field is 1024. Use BatchTranslateText for larger text.
glossary_config: Option<TranslateTextGlossaryConfig>Optional. Glossary to be applied. The glossary must be within the same region (have the same location-id) as the model, otherwise an INVALID_ARGUMENT (400) error is returned.
labels: Option<HashMap<String, String>>Optional. The labels with user-defined metadata for the request. Label keys and values can be no longer than 63 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter. See https://cloud.google.com/translate/docs/advanced/labels for more information.
mime_type: Option<String>Optional. The format of the source text, for example, “text/html”, “text/plain”. If left blank, the MIME type defaults to “text/html”.
model: Option<String>Optional. The model type requested for this translation. The format depends on model type: - AutoML Translation models: projects/{project-number-or-id}/locations/{location-id}/models/{model-id} - General (built-in) models: projects/{project-number-or-id}/locations/{location-id}/models/general/nmt, - Translation LLM models: projects/{project-number-or-id}/locations/{location-id}/models/general/translation-llm, For global (non-regionalized) requests, use location-id global. For example, projects/{project-number-or-id}/locations/global/models/general/nmt. If not provided, the default Google model (NMT) will be used
source_language_code: Option<String>Optional. The ISO-639 language code of the input text if known, for example, “en-US” or “sr-Latn”. Supported language codes are listed in Language Support. If the source language isn’t specified, the API attempts to identify the source language automatically and returns the source language within the response.
target_language_code: Option<String>Required. The ISO-639 language code to use for translation of the input text, set to one of the language codes listed in Language Support.
transliteration_config: Option<TransliterationConfig>Optional. Transliteration to be applied.