pub struct TranslateTextResponse {
pub glossary_translations: Option<Vec<Translation>>,
pub translations: Option<Vec<Translation>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations translate text projects (response)
- translate text projects (response)
Fields
glossary_translations: Option<Vec<Translation>>Text translation responses if a glossary is provided in the request. This can be the same as translations if no terms apply. This field has the same length as contents.
translations: Option<Vec<Translation>>Text translation responses with no glossary applied. This field has the same length as contents.