pub struct Translation {
pub detected_language_code: Option<String>,
pub glossary_config: Option<TranslateTextGlossaryConfig>,
pub model: Option<String>,
pub translated_text: Option<String>,
}Expand description
A single translation response.
This type is not used in any activity, and only used as part of another schema.
Fields
detected_language_code: Option<String>The ISO-639 language code of source text in the initial request, detected automatically, if no source language was passed within the initial request. If the source language was passed, auto-detection of the language does not occur and this field is empty.
glossary_config: Option<TranslateTextGlossaryConfig>The glossary_config used for this translation.
model: Option<String>Only present when model is present in the request. model here is normalized to have project number. For example: If the model requested in TranslationTextRequest is projects/{project-id}/locations/{location-id}/models/general/nmt then model here would be normalized to projects/{project-number}/locations/{location-id}/models/general/nmt.
translated_text: Option<String>Text translated into the target language. If an error occurs during translation, this field might be excluded from the response.