pub struct TransliterationConfig {
pub enable_transliteration: Option<bool>,
}Expand description
Configures transliteration feature on top of translation.
This type is not used in any activity, and only used as part of another schema.
Fields
enable_transliteration: Option<bool>If true, source text in romanized form can be translated to the target language.