pub struct DocumentTranslation {
pub byte_stream_outputs: Option<Vec<Vec<u8>>>,
pub detected_language_code: Option<String>,
pub mime_type: Option<String>,
}Expand description
A translated document message.
This type is not used in any activity, and only used as part of another schema.
Fields
byte_stream_outputs: Option<Vec<Vec<u8>>>The array of translated documents. It is expected to be size 1 for now. We may produce multiple translated documents in the future for other type of file formats.
detected_language_code: Option<String>The detected language for the input document. If the user did not provide the source language for the input document, this field will have the language code automatically detected. If the source language was passed, auto-detection of the language does not occur and this field is empty.
mime_type: Option<String>The translated document’s mime type.