pub struct TranslateDocumentRequest {
pub customized_attribution: Option<String>,
pub document_input_config: Option<DocumentInputConfig>,
pub document_output_config: Option<DocumentOutputConfig>,
pub enable_rotation_correction: Option<bool>,
pub enable_shadow_removal_native_pdf: Option<bool>,
pub glossary_config: Option<TranslateTextGlossaryConfig>,
pub is_translate_native_pdf_only: Option<bool>,
pub labels: Option<HashMap<String, String>>,
pub model: Option<String>,
pub source_language_code: Option<String>,
pub target_language_code: Option<String>,
}Expand description
A document translation request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations translate document projects (request)
Fields
customized_attribution: Option<String>Optional. This flag is to support user customized attribution. If not provided, the default is Machine Translated by Google. Customized attribution should follow rules in https://cloud.google.com/translate/attribution#attribution_and_logos
document_input_config: Option<DocumentInputConfig>Required. Input configurations.
document_output_config: Option<DocumentOutputConfig>Optional. Output configurations. Defines if the output file should be stored within Cloud Storage as well as the desired output format. If not provided the translated file will only be returned through a byte-stream and its output mime type will be the same as the input file’s mime type.
enable_rotation_correction: Option<bool>Optional. If true, enable auto rotation correction in DVS.
enable_shadow_removal_native_pdf: Option<bool>Optional. If true, use the text removal server to remove the shadow text on background image for native pdf translation. Shadow removal feature can only be enabled when is_translate_native_pdf_only: false && pdf_native_only: false
glossary_config: Option<TranslateTextGlossaryConfig>Optional. Glossary to be applied. The glossary must be within the same region (have the same location-id) as the model, otherwise an INVALID_ARGUMENT (400) error is returned.
is_translate_native_pdf_only: Option<bool>Optional. is_translate_native_pdf_only field for external customers. If true, the page limit of online native pdf translation is 300 and only native pdf pages will be translated.
labels: Option<HashMap<String, String>>Optional. The labels with user-defined metadata for the request. Label keys and values can be no longer than 63 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter. See https://cloud.google.com/translate/docs/advanced/labels for more information.
model: Option<String>Optional. The model type requested for this translation. The format depends on model type: - AutoML Translation models: projects/{project-number-or-id}/locations/{location-id}/models/{model-id} - General (built-in) models: projects/{project-number-or-id}/locations/{location-id}/models/general/nmt, If not provided, the default Google model (NMT) will be used for translation.
source_language_code: Option<String>Optional. The ISO-639 language code of the input document if known, for example, “en-US” or “sr-Latn”. Supported language codes are listed in Language Support. If the source language isn’t specified, the API attempts to identify the source language automatically and returns the source language within the response. Source language must be specified if the request contains a glossary or a custom model.
target_language_code: Option<String>Required. The ISO-639 language code to use for translation of the input document, set to one of the language codes listed in Language Support.